import { Request, Response } from 'node-fetch';
import { JwtVerifierOptions, JwtVerifierError } from '@serverless-jwt/jwt-verifier';
export interface CloudflareAuthenticatedWorker {
    (identityContext: IdentityContext, request: Request): Promise<Response>;
}
interface CloudflareJwtVerifier {
    (handler: CloudflareAuthenticatedWorker): (request: Request) => Promise<Response>;
}
interface CloudflareJwtVerifierOptions extends JwtVerifierOptions {
    /**
     * Customize how errors are handled.
     */
    handleError?(err: Error | JwtVerifierError): Response;
}
export interface IdentityContext {
    /**
     * The token that was provided.
     */
    token: string;
    /**
     * Claims for the authenticated user.
     */
    claims: Record<string, unknown>;
}
/**
 * Return a JSON response.
 * @param statusCode
 * @param body
 */
export declare const json: (statusCode: number, body: Record<string, unknown>) => Response;
/**
 * Create a JWT verifier handler.
 * @param options
 */
export declare const CloudflareJwtVerifier: (options: CloudflareJwtVerifierOptions) => CloudflareJwtVerifier;
export { claimToArray, removeNamespaces, getTokenFromHeader } from '@serverless-jwt/jwt-verifier';
